@@ -67,10 +67,12 @@ def try_upsert(collection: StandardCollection, record_batch: RecordBatch, force=
     if record_batch.length() >= record_batch.max_batch_size or force:
         to_insert = record_batch.flush()
         to_update = []
+        logger.info("To insert: %s", to_insert)
         for i, r in enumerate(collection.insert_many(to_insert)):
             if type(r) is DocumentInsertError:
                 to_update.append(to_insert[i])
         if len(to_update) > 0:
+            logger.info("To update: %s", to_update)
             for i, r in enumerate(collection.update_many(to_update)):
                 if type(r) is DocumentInsertError:
                     print(f'Failed to insert/update record: {to_update[i]}. {r}')
@@ -112,12 +114,14 @@ def persist_messages(collection: StandardCollection, messages: io.TextIOWrapper,
             try:
                 rec = o['record']
                 try:
+                    logger.info("Debug Record before %s", rec)
                     kps = key_properties.get('stream')
                     _key = None
                     # Appending _ to keys inorder for preserving values of reserved keys in source data
                     reserved_keys = ['_key', '_id', '_rev']
 
                     if kps:
+                        logger.info("Debug Key Properties %s", kps[0])
                         if len(kps) > 1:
                             logger.warn(f'Multiple key_properties found ({",".join(kps)}).'
                                         f' Only `{kps[0]}` will be considered.')
@@ -140,8 +144,11 @@ def persist_messages(collection: StandardCollection, messages: io.TextIOWrapper,
                         _key = hashed_key.hexdigest()
                         logger.info(f"Primary key of the source doesn't satisfy the constraints of macrometa "
                                     f"document key, Hashing the key and using it in hex form to make it compliant.")
+                    if _key:
                         rec['_key'] = _key
-                except:
+                    logger.info("Debug Record is %s", rec)
+                except Exception as e:
+                    logger.info("Exception %s", e)
                     _key = None
                 if '_sdc_deleted_at' in rec:
                     if rec['_sdc_deleted_at']:
